//FAIRE UN TEST SUR LES DATAS (rajout, agrandissement des zones, passage en password etc..)
//COMMENTAIRE PROPOSE ET REFUSE AVEC CARACTERE SPECIAUX
//TEST SUR L'ONGLET (STAGGING ou WORKING AREA) ouvert par défaut
//TEST casse l'héritage des données normal et protégé SEF-4610
//TEST SUR LES CHECKS QUI SONT DES BP_RULES ==> impossibilté de faire la maj du champ check_command
//SEF-4608
//SEF-4858
//      cd /root/tools/undelivered/flask_server_add_daemons_route
//      python3.9 flask_server_add_daemons_route.py


var __is_log_mute        = SHINKEN.HIGHWAY.getParams( 'mute' );
var __shinken_test_type  = SHINKEN.HIGHWAY.getParams( 'shinken_test_auto' );
var __is_single          = SHINKEN.HIGHWAY.getParams( 'single' );
var __phase              = parseInt( SHINKEN.HIGHWAY.getParams( 'phase' ) ) || 1;
var __window_phase       = parseInt( SHINKEN.HIGHWAY.getParams( 'window_phase' ) ) || '';
var _has_script_error    = 0;
var __do_next            = true;
var __time_start_for_log = Date.now();

var _current;
var _property_name;
var _current_data_host;
var _current_data_check;
var _current_data_host_tpl;
var _current_data_host_tpl_01;
var _current_data_host_tpl_02;
var _current_data_host_tpl_03;


var __doActionWhenReadyDocumentation_done = false;

var doActionWhenReadyTestAuto = function () {
    if ( __doActionWhenReadyDocumentation_done ) {
        return;
    }
    __doActionWhenReadyDocumentation_done = true;
    
    function ____ ( fct_timeout ) {
        _timeout += fct_timeout;
    }
    
    SHINKEN.TOOLS.TEST_AUTO_LOGGER.init();
    var _timeout = 0;
    if ( __phase === 99 ) {
        return;
    }
    if ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ] && SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].version_minimum ) {
        if ( __version_shinken < SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].version_minimum ) {
            SHINKEN.TOOLS.TEST_AUTO.buildMessage( _timeout );
            return;
        }
    }
    if ( !__window_phase ) {
        switch ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].testable_status ) {
            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.EXCLUDE :
                SHINKEN.TOOLS.TEST_AUTO.addError( "test exclude" );
                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
                return;
            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.DISCONTINUED :
                SHINKEN.TOOLS.TEST_AUTO.addError( "test discontinued" );
                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
                break;
            case SHINKEN.TOOLS.TEST_AUTO.CONST.TESTABLE_STATUS.IN_DEVELOPMENT :
                SHINKEN.TOOLS.TEST_AUTO.addError( "test in development" );
                SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
                break;
        }
    }
    
    switch ( __shinken_test_type ) {
        case "DEV":
            //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
            __do_next = false;
            break;
        case "DEV_METEO":
            ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
            //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO.ACTION.do_JS_action( _timeout, "DOM.Service.removeElement(document.querySelectorAll('.shinken-json-line-end')[25])", 1000 ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'preview_weather' ) );
            break;
        case "DEV_DUPLICATE_ADDRESS":
            //____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "duplicated_accepted" ) );
            //____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "warning_displayed" ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "error_displayed" ) );
            //____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "save_forbidden" ) );
            break;
        case "DEV-SEF-7814-1":
            setTimeout( function () {
                var _prop       = MANAGER.__instance_property_distributor.getElement( PROPERTY.CONST.NAME.OUTPUT_RULES );
                var _button_add = _prop.dom_element.querySelector( '.shinken-multi-line-object-button-plus' );
                _button_add.click();
                setTimeout( function () {
                    var _input           = _prop.lines_object[ 0 ].inputs[ 'shinken-input-container-cell' ];
                    _input.current_value = '<span onclick="alert()"><b>toto</b></span>';
                    _input.updateView();
                    _prop.askComputeAfterChange( _input.dom_element );
                }, 1000 );
            }, 1000 );
            break;
        case "TEST_SOURCE":
            __do_next     = false;
            var _elements = document.querySelectorAll( ".icon-eye-open" );
            for ( var i = 0, _size_i = _elements.length; i < _size_i; i++ ) {
                ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, _elements[ i ] ) );
            }
            break;
        case "00029":
            //SOURCE TO FINISH
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.TEST.numberTabs( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.TEST.forceImportButtonStatus( _timeout, COMPONENT.CONST.BTN_STATE.ON ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.TEST.forceImportButtonStatus( _timeout, COMPONENT.CONST.BTN_STATE.OFF ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    break;
                case 3:
                    _timeout += 5000;
                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.TEST.forceImportButtonStatus( _timeout, COMPONENT.CONST.BTN_STATE.ON ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.forceImport( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.forceImport( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    //__do_next = false;
                    break;
            }
            break;
        case "00031":
            
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout, true ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceExisting( _timeout, SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER, true ) );
                    break;
                case 2:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnAddDistantSynchronizer( _timeout ) );
                    break;
                case 3:
                    __do_next = false;
                    _timeout += 1000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "sync_name", "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "51.15.206.188" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "contact_name", "Shinken" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "password", "Shinken" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.OFF] ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnActivateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
                    break;
                case 5:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
                    break;
                case 6:
                    _timeout += 1000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "prefix", "TEST_AUTO_2" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout ) );
                    break;
                case 7:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnAddDistantSynchronizer( _timeout ) );
                    break;
                case 8:
                    _timeout += 1000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "sync_name", "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "address", "51.15.206.188" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "contact_name", "Shinken" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.setValue( _timeout, "password", "Shinken" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.save( _timeout, true ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.hasFormError( _timeout ) );
                    break;
                case 9:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.forceImport( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'MANAGER.__instance_source_distributor.findSource("' + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + '").fully_merged' ) );
                    break;
                case 10:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-detail-last-run" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerListLength( _timeout, 1 ) );
                    break;
                case 11:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-synchronizers-list" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerList( _timeout, 1, [COMPONENT.CONST.BTN_STATE.ON] ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.clickOnUpdateDistantSynchronizer( _timeout, "TEST_AUTO_1" ) );
                    break;
                case 12:
                    __do_next = false;
                    _timeout += 1000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete( _timeout ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.ACTION.FORM.delete(' + _timeout + ')' ) );
                    break;
                case 13:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.forceImport( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PHASE.doNextWhen( _timeout, 'MANAGER.__instance_source_distributor.findSource("' + SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER + '").fully_merged' ) );
                    
                    break;
                case 14:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-detail-last-run" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER.TEST.distantSynchronizerListLength( _timeout, 0 ) );
                    break;
            }
            break;
        case "00081":
            //PAGE MAIN
            switch ( __phase ) {
                case 1:
                    if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA || __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
                        break;
                    }
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.DOM.getStaging() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.DOM.getStaging(), 'display', 'block' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.DOM.getSourcesAndTaggers() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.DOM.getSourcesAndTaggers(), 'display', 'block' ) );
                    // A REFAIRE AVEC NOUVEAU FORMAT
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.getSourcesContainer()) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.getSourcesContainer(), 'display', 'inline-block', 'block sources' ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.getSourcesContainer(), 'displayAll', '0', 'block sources' ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-analyzer" ), "le block de sources ANALYSZER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-listener" ), "le block de sources LISTENER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-collector" ), "le block de sources COLLECTOR" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-table-tagger-main-page" ), "le block TAGGER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.querySelector( "#id-shinken-container-source-all" ), "la liste des sources all" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout, true ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-all" ), "la liste des sources all" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.querySelector( "#id-shinken-container-source-analyzer" ), "le block de sources ANALYSZER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.querySelector( "#id-shinken-container-source-listener" ), "le block de sources LISTENER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.querySelector( "#id-shinken-container-source-collector" ), "le block de sources COLLECTOR" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-table-tagger-main-page" ), "le block TAGGER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( ".content-staging" ) ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-analyzer" ), "le block de sources ANALYSZER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-listener" ), "le block de sources LISTENER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-container-source-collector" ), "le block de sources COLLECTOR" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.querySelector( "#id-shinken-table-tagger-main-page" ), "le block TAGGER" ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.querySelector( "#id-shinken-container-source-all" ), "la liste des sources all" ) );
                    break;
            }
            break;
        case "00100":
        case "00101":
        case "00102":
        case "00103":
        case "00104":
        case "00105":
        case "00106":
        case "00107":
        case "00108":
        case "00109":
        case "00110":
        case "00111":
        case "00112":
        case "00113":
        case "00114":
        case "00115":
        case "00116":
        case "00117":
        case "00118":
        case "00119":
            //MASS CHANGE
            _timeout = 1000;
            SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout );
            setTimeout( function () {
                var _temp_timeout      = 200;
                var _waiting_dom_ready = setInterval( function () {
                    if ( CONTROLLER.MassChange.steps.current === OBJECT.CONST.STEP._1 ) {
                        clearInterval( _waiting_dom_ready );
                        setTimeout( function () {
                            SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.validStep1Display();
                        }, 2000 );
                    }
                    _temp_timeout = +600;
                }, 600 );
            }, _timeout );
            _timeout += 5000;
            break;
        
        
        
        case "00130":
            if ( !SHINKEN.TOOLS.ENCRYPTION.isProtectedFieldsActivated() ) {
                console.warn( "GREG", "[00130]", "Ce test ne peut se faire que si le chiffrement est activé" );
                break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.DATAS ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, "test_auto_valid_2" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, "test_auto_valid_2" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.CHECKS_OVERRIDE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnSelectAllStep2( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step2ToStep3( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.DATAS ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, "test_auto_valid_2" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.PASSWORD.KEY_NAME, "test_auto_valid_2" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.USE, "00003_test_auto_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                    break;
            }
            break;
        
        case "00132":
            if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA || __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
                break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.DATAS ) );
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "TEST_AUTO", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "test_auto_2", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 1, 2, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 1, 2, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "test_auto_3'", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 1, 1, 3, 5 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 1, 1, 3, 5 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 5 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "test_auto", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 1, 1 ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000009", 0, 0, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000009", 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "TEST_AUTO", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "test_auto_2", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "test_auto_3'", "test_auto" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 1, 1, 4, 8 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 1, 1, 4, 6 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000009", 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 6 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 8 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 1, 1, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.removeFirstData( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 1, 3 ) );
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_2", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_LOCAL_DATA", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_LOCAL_DATA", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 2, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 1, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000009", 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 2 ) );
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'TPL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'LOCAL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, "12000000000000000000000000000009" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'TPL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, '' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 4 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.FORCE_TO_DEFAULT ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_2", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.EMPTY_DATA ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_3", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_IS_SET_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_3", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_LOCAL_DATA", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_LOCAL_DATA", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 4 ) );
                    break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
            break;
        case "00133":
            if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA || __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
                break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.DFE_DATAS ) );
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000010", 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_LOCAL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_LOCAL_DFE_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 1 ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000010", 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_DFE_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000010", 0, 0, 1, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 1, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 1 ) );
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_DFE_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_DFE_2", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_OR_CREATE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_DFE_2", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 2, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 0, 0, 0, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "12000000000000000000000000000010", 0, 0, 2, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_LOCAL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_LOCAL_DFE_1", "test_auto_valid$(bad" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 1, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 1, 0, 3, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL, 1, 0, 1, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_LOCAL_DFE_1", "test_auto_valid$(value1,value2)$,test_auto_valid_1$(value3,value2)$" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 3 ) );
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'TPL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.LOCAL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'LOCAL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, "12000000000000000000000000000010" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, 'TPL' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.clickOnGroupData( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addFilterValue( _timeout, '' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_LOCAL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.FORCE_TO_DEFAULT ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_DFE_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.EMPTY_DATA ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_TPL_DFE_2", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_IS_SET_ON_ITEM ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_TPL_DFE_2", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 3 ) );
                    break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
            break;
        case "00134":
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.CHECKS_OVERRIDE ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnSelectAllStep2( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step2ToStep3( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.DATAS ) );
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.countDisplayedData( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataList( _timeout, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, CONTROLLER.CONST.MASS_CHANGE.GROUP_DATA.ALL, 0, 0, 0, 3 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "22000000000000000000000000000134", 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.TEST.validGroupDataCounter( _timeout, "22100000000000000000000000000134", 0, 0, 0, 2 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_CHECK_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_EXISTS_ON_ITEM_OVERRIDE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_CHECK_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 1 ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_CHECK_1", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET_IF_DATA_IS_SET_ON_ITEM_OVERRIDE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, "_TEST_AUTO_CHECK_1", "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, "_TEST_AUTO_CHECK_2", PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.EMPTY_DATA_OVERRIDE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.counterNextButton( _timeout, 3, 0, 0, 2 ) );
                    break;
            }
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
            break;
        
        
        case "00158":
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTab() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-network-scan" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-network-scan-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-analyzer-template-mapping" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-analyzer-template-mapping-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-summary-old-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-summary-old-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-detail-last-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-detail-last-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTabMenu() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTab() ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-network-scan" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAddNetworkRange( _timeout ) );
                    __do_next = false;
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "discovery_name", "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "iprange", SHINKEN.HIGHWAY.getHostName() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.save( _timeout ) );
                    __do_next = false;
                    break;
                case 4:
                    var _instance_navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
                    _timeout += 3000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-network-scan", _instance_navigator ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAnalyzerButton( _timeout, "TEST_AUTO_1", _instance_navigator ) );
                    _timeout += 3000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnLaunchAnalyzeButton( _timeout, _instance_navigator ) );
                    _timeout += 25000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnLaunchAnalyzeButton( _timeout, _instance_navigator ) );
                    _timeout += 25000;
                    setTimeout( function () {
                        SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
                        SHINKEN.HIGHWAY.refreshCurrentPage();
                        _instance_navigator.close();
                    }, 60000 );
                    break;
                case 5:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-summary-old-run" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LAST_RUN_TAB.ACTION.clickOnLastRunByIndex( _timeout, 1 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LAST_RUN_TAB.ACTION.clickOnLastRunByIndex( _timeout, 0 ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LAST_RUN_TAB.ACTION.clickOnLastRunByIndex( _timeout, 1 ) );
                    break;
            }
            break;
        case "00159":
        case "00160":
        case "00161":
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTab() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-summary-old-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-summary-old-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-detail-last-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-detail-last-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTabMenu() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTab() ) );
                    break;
            }
            break;
        case "00162":
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-rules" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-rules-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-network-scan" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-network-scan-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-summary-old-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-summary-old-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, document.getElementById( "id-shinken-window-detail-last-run" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( "tab-pane-detail-last-run-target" ) ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTabMenu() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.DOM.getTab() ) );
                    break;
            }
            break;
        case "00167":
            ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "warning_displayed" ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.ADDRESS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.ADDRESS, 'test_auto' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnSelectAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapse( _timeout, "00000000000000000000000000000001" ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.collapseAllStatus( _timeout, SHINKEN.TOOLS.TEST_AUTO_PROPERTY_CONST.STATE.UN_COLLAPSED ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapse( _timeout, "00000000000000000000000000000001" ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.collapseAllStatus( _timeout, SHINKEN.TOOLS.TEST_AUTO_PROPERTY_CONST.STATE.COLLAPSED ) );
            break;
        case "00168":
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.LOCAL_DATAS ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_DATA.ACTION.addNewData( _timeout, "TEST_AUTO", "1" ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnSelectAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnSelectAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnSelectAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnSelectAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.FILTER_CONST.ELEMENTS, '00001_test_auto' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.FILTER_CONST.ELEMENTS, '' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.FILTER_CONST.ACTION, 'OK' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step4ToStep5( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.ACTION.clickOnCollapseAll( _timeout ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.FILTER_CONST.ACTION, 'OK' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.FILTER_CONST.ELEMENTS, '00001_test_auto' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.FILTER_CONST.ELEMENTS, '00000_test_auto' ) );
            ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.ACTION.setFilterValue( _timeout, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_5.FILTER_CONST.ELEMENTS, '' ) );
            break;
        case "00169":
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "error_displayed" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.CHECKS_OVERRIDE ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnSelectAllStep2( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step2ToStep3( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.BUSINESS_IMPACT, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.BUSINESS_IMPACT, "3" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.ACTION.clickOnCollapseAll( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                    _timeout += 5000;
            }
            break;
        case "00170":
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "error_displayed" ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.ADDRESS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.ADDRESS, 'test_auto' ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.WORKING_AREA ) );
                    _timeout += 2000; //NEEDED TO COMPUTE THE CHANGE
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step4ToStep3( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.TEST.currentStep( _timeout, 4 ) );
            }
            break;
        case "00171":
            ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone( _timeout ) );
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, "test_auto_valid" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_SELECT.ACTION.setBtnPlus( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, COMPONENT.CONST.BTN_STATE.ON ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                    break;
                case 3:
                    _timeout += TIMEOUT_SAVING_LOG_SUCCESS;
                    ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, document.getElementById( "saving-log-title-text" ) ) );
                    break;
            }
            break;
        case "00172":
            //TEST SOURCE VMWARE
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-configuration" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-host_template_binding_rules" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-mapping_origin_to_source" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-summary-old-run" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-detail-last-run" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-configuration" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.COMPUTE_NEW_ELEMENT, "1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.COMPUTE_ELEMENT_DIFFERENCE, "1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.DOWNTIME_ON_DELETE_ELEMENT_ACTIVATED, "0" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.DOWNTIME_ON_DELETE_ELEMENT_API_USE_SSL, "0" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.MERGE_MODE, "all" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.COMPUTE_DELETED_ELEMENT_NOT_IN_SOURCE, "disabled" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.JS.defaultValue( _timeout, PROPERTY.CONST.NAME_IN_SOURCE.PUT_IN, "source_space" ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-host_template_binding_rules" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.ACTION.clickOnHelpButton( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.ACTION.clickCloseHelpButton( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.ACTION.setInputFilter( _timeout, "name", "esx" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.TEST.filterStatus( _timeout, "name", COMPONENT.CONST.BTN_STATE.ON ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.TEST.filterStatus( _timeout, "index", COMPONENT.CONST.BTN_STATE.OFF ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.ACTION.setInputFilter( _timeout, "name", "" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.TEST.filterStatus( _timeout, "name", COMPONENT.CONST.BTN_STATE.OFF ) );
                    //____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_TEMPLATE_BINDING.ACTION.setSelectFilter( _timeout, "counters", "___NOT_EMPTY___" ) );
                    break;
                case 3:
                    break;
                case 4:
                    break;
                case 5:
                    break;
            }
            break;
        case "00191":
            //source discovery
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout, true ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceExisting( _timeout, "discovery" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, "discovery", true ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceState( _timeout, "discovery", SOURCE.CONST.STATE.NOT_CONFIGURED ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DISCOVERY.ACTION.FORM.setValue( _timeout, "discovery_name", "TEST_AUTO_1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DISCOVERY.ACTION.FORM.setValue( _timeout, "iprange", SHINKEN.HIGHWAY.getHostName() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DISCOVERY.ACTION.FORM.save( _timeout ) );
                    __do_next = false;
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.switchListSourceDisplay( _timeout, true ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceState( _timeout, "discovery", SOURCE.CONST.STATE.READY_FOR_IMPORT ) );
                    break;
            }
            break;
        case "00198":
            // Test cliquable links in syncui "imported_from"
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DETAIL_LAST_RUN_TAB.ACTION.openAllDetails( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DETAIL_LAST_RUN_TAB.TEST.linkForElementDetail( _timeout, 1 ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DETAIL_LAST_RUN_TAB.ACTION.openAllDetails( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_DETAIL_LAST_RUN_TAB.TEST.linkForElementDetail( _timeout, 0 ) );
                    break;
            }
            break;
        case "00204":  //CHECK XSS INJECTION ON ANALYSER CONFIGURATION PANEL
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.switchSourceActivity( _timeout, SOURCE__NAME__SERVER__ANALYZER, true ) );
                    break;
                case 2:
                    __do_next = false;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.setConfiguration( _timeout, "linux__login", SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.ACTION.submitForm( _timeout ) );
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-network-scan" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.deleteIpRangeByRequest( _timeout, [200, 400], false, "00204-1" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAddNetworkRange( _timeout ) );
                    __do_next = false;
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "discovery_name", "test_auto_204" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.setValue( _timeout, "iprange", SHINKEN.HIGHWAY.getHostName() ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.FORM.save( _timeout ) );
                    __do_next = false;
                    break;
                case 5:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnAnalyzerButton( _timeout, "test_auto_204" ) );
                    __do_next = false;
                    break;
                case 6:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnLaunchAnalyzeButton( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_XSS.isFunctionExisting( _timeout ) );
                    break;
                
            }
            break;
        case "00213":  //SEF-9714
            ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LAST_RUN_TAB.TEST.elementSendToSynchronizer( _timeout ) );
            break;
        case "00214":  //SEF-9676
            switch ( __phase ) {
                case 1:
                    var _instance_navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
                    _timeout += 3000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE.ACTION.navigateInTab( _timeout, "tab-analyzer-template-mapping", _instance_navigator ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.setValueToMappingTemplate( _timeout, "Operating Systems__linux", SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, _instance_navigator ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_ANALYZER.ACTION.clickOnSubmitMappingTemplate( _timeout, _instance_navigator ) );
                    setTimeout( function () {
                        _instance_navigator.close();
                    }, 3000 + 200 + 500 + 3000 );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_XSS.isFunctionExisting( _timeout ) );
                    break;
                
            }
            break;
        case "00232":  //SEF-9785
            ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.ifCodeIsPresent( _timeout, "after_scheduler_configuration_load", "/daemons/schedulerdaemon.py" ) );
            break;
        case "00237": //SEF-10733
            var _error = function ( err ) {
                SHINKEN.TOOLS.TEST_AUTO.addError( err );
                SHINKEN.TOOLS.TEST_AUTO.addError( "IS SERVER FLASK RUNNING ??" );
            };
            switch ( __phase ) {
                case 1 :
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.fileNotExist( _timeout, "/var/lib/shinken/libexec/analyzer/impacket/examples/secretsdump.py", false, _error ) );
                    break;
                case 2 :
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.fileNotExist( _timeout, "/var/lib/shinken/libexec/analyzer/impacket/examples/secretsdump.pyo", false, _error ) );
                    break;
            }
            break;
        case "00238" :
            switch ( __phase ) {
                case 1 :
                    if ( MANAGER.__instance_element_distributor.current_user.uuid !== '33000000000000000000000000000000' ) {
                        SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_admin_si", "test_auto_admin_si" );
                    }
                    _timeout += 4000;
                    break;
                case 2 :
                    var _navigator = window.open( SHINKEN.HIGHWAY.getPath(), "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
                    
                    _timeout += 3000;
                    setTimeout( function () {
                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, SHINKEN.TOOLS.TEST_AUTO_UI_CONFIGURATION_MENU.DOM.btnProduction( _navigator ) ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.TEST.redirect( _timeout, _navigator.location.pathname, "/main" ) );
                    }, _timeout );
                    setTimeout( function () {
                        _navigator.close();
                    }, _timeout + 2000 );
                    break;
                case 3 :
                    SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                    _timeout += 4000;
                    break;
            }
            break;
        case "go":
        case "00000":
            __shinken_test_type = "00000";
            switch ( __phase ) {
                case 1:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.addSourceIfNotExist( _timeout, SOURCE__MODULE_TYPE__CFG_FILE_IMPORT, SOURCE__NAME__TEST_AUTO ) );
                    break;
                case 2:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.addSourceIfNotExist( _timeout, SOURCE__MODULE_TYPE__LISTENER_TEST_AUTO, SOURCE__NAME__LISTENER_TEST_AUTO, SOURCE__PORT__LISTENER_TEST_AUTO ) );
                    break;
                case 3:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.addSourceIfNotExist( _timeout, SOURCE__MODULE_TYPE__COLLECTOR_SYNCHRONIZER_LINKER, SOURCE__NAME__SYNCHRONIZER_COLLECTOR_LINKER ) );
                    break;
                case 4:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.addSourceIfNotExist( _timeout, SOURCE__MODULE_TYPE__COLLECTOR_SYNCHRONIZER_VMWARE, SOURCE__NAME__SYNCHRONIZER_COLLECTOR_VMWARE ) );
                    break;
                case 5:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.TEST.isSourceExisting( _timeout, SOURCE__NAME__CFG_FILE_SHINKEN ) );
                    break;
                case 6:
                    ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "admin", "admin" ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.dropAllDatabases( _timeout ) );
                    break;
                case 7:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.enableSources( _timeout, SOURCE__LIST_NEEDED_FOR_TEST_AUTO ) );
                    break;
                case 11:
                    break;
                case 12:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SOURCE_CONFIGURATION_TAB.ACTION.addConfiguration( _timeout, SOURCE.CONST.TYPES.LISTENER, "Shinken", "Shinken", "SHINKEN.TOOLS.TEST_AUTO.buildMessage( 0 )" ) );
                    __do_next = false;
                    break;
                case 13:
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.forceImport( _timeout, SOURCE__NAME__TEST_AUTO ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MAIN_PAGE.ACTION.forceImport( _timeout, SOURCE__NAME__CFG_FILE_SHINKEN ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.initShinkenElementsSyncUIListener( _timeout ) );
                    _timeout += 8000;
                    break;
                case 14:
                case 16:
                    ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.IMPORT ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                    break;
                case 18:
                    ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.initShinkenElementsSyncUI( _timeout ) );
                    _timeout += 4000;
                    break;
                case 19:
                    if ( MANAGER.__instance_element_distributor.current_user.uuid !== '35000000000000000000000000000000' ) {
                        SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                    }
                    _timeout += 4000;
                    break;
                case 20:
                    ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                    _timeout += 4000;
                    break;
                case 21:
                    _timeout += 4000;
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.TEST.activateWeatherModule( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.restart( _timeout ) );
                    break;
            }
            break;
        case "delete":
        case "remove":
            window.open( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ "delete_1" ].address, '_blank' );
            _timeout += 5000;
            break;
        case "delete1":
            document.getElementById( 'all-changes-checkbox' ).click();
            document.querySelector( ".shinken-option[data-key-name='delete']" ).click();
            launch_select_action( false );
            setTimeout( function () {
                window.open( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ "delete_2" ].address, '_blank' );
            }, 5000 );
            __do_next = false;
            break;
        case "delete2":
            document.getElementById( 'all-changes-checkbox' ).click();
            document.querySelector( ".shinken-option[data-key-name='delete']" ).click();
            launch_select_action( false );
            __do_next = false;
            break;
        default:
            ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT_RUN.do( _timeout ) );
            break;
        
    }
    if ( !__window_phase ) {
        SHINKEN.TOOLS.TEST_AUTO.MakeFinalAction( _timeout );
    }
};


window.onerror = function () {
    _has_script_error++;
};

document.addEventListener( "DOMContentLoaded", function ( e ) {
    setTimeout( function () {
        doActionWhenReadyTestAuto();
    }, 1000 );
} );